@@ -1,6 +1,6 @@
 #!/usr/bin/env perl
 # PODNAME: classify-ali.pl
-# ABSTRACT: Classify ALI files according to multiple (taxonomic) criteria
+# ABSTRACT: Classify ALI files based on taxonomic filters
 
 use Modern::Perl '2011';
 use autodie;
@@ -54,7 +54,7 @@ for my $indir (@ARGV_indirs) {
 
         ### Processing: $infile
         my $ali = Ali->load($infile);
-        $ali->dont_guess if $ARGV_noguessing;
+        $ali->dont_guess;
 
         # classify Ali
         my $cat_label = $classifier->classify($ali);
@@ -64,7 +64,7 @@ for my $indir (@ARGV_indirs) {
         # store Ali in corresponding directory
         my $subdir = dir($outdir, $cat_label)->relative;
         my ($filename) = fileparse($infile);
-        my $outfile = file($subdir, $filename)->stringify;
+        my $outfile = file($subdir, $filename);
         $ali->store($outfile);
     }
 }
@@ -75,11 +75,11 @@ __END__
 
 =head1 NAME
 
-classify-ali.pl - Classify ALI files according to multiple (taxonomic) criteria
+classify-ali.pl - Classify ALI files based on taxonomic filters
 
 =head1 VERSION
 
-version 0.181000
+version 0.210120
 
 =head1 USAGE
 
@@ -172,10 +172,6 @@ Path to local mirror of the NCBI Taxonomy database.
 
 =over
 
-=item --[no]guessing
-
-[Don't] guess whether sequences are aligned or not [default: yes].
-
 =item --version
 
 =item --usage
